@@ -28,6 +28,8 @@ _VAR_KWARGS_NOT_ALLOWED = 'Spec subclasses must not accept **kwargs.'
 _MINIMUM_MUST_BE_LESS_THAN_OR_EQUAL_TO_MAXIMUM = (
     'All values in `minimum` must be less than or equal to their corresponding '
     'value in `maximum`, got:\nminimum={minimum!r}\nmaximum={maximum!r}.')
+_MINIMUM_INCOMPATIBLE_WITH_SHAPE = '`minimum` is incompatible with `shape`'
+_MAXIMUM_INCOMPATIBLE_WITH_SHAPE = '`maximum` is incompatible with `shape`'
 
 
 class Array:
@@ -168,7 +170,7 @@ class BoundedArray(Array):
   integer types. The following spec will be satisfied by arrays
   with values in the set {0, 1, 2}:
   ```python
-  spec = BoundedArray((3, 4), np.int, minimum=0, maximum=2)
+  spec = BoundedArray((3, 4), int, minimum=0, maximum=2)
   ```
 
   Note that one or both bounds may be infinite. For example, the set of
@@ -207,14 +209,11 @@ class BoundedArray(Array):
     try:
       bcast_minimum = np.broadcast_to(minimum, shape=shape)
     except ValueError as numpy_exception:
-      raise ValueError('minimum is not compatible with shape. '
-                       'Message: {!r}.'.format(numpy_exception))
-
+      raise ValueError(_MINIMUM_INCOMPATIBLE_WITH_SHAPE) from numpy_exception
     try:
       bcast_maximum = np.broadcast_to(maximum, shape=shape)
     except ValueError as numpy_exception:
-      raise ValueError('maximum is not compatible with shape. '
-                       'Message: {!r}.'.format(numpy_exception))
+      raise ValueError(_MAXIMUM_INCOMPATIBLE_WITH_SHAPE) from numpy_exception
 
     if np.any(bcast_minimum > bcast_maximum):
       raise ValueError(_MINIMUM_MUST_BE_LESS_THAN_OR_EQUAL_TO_MAXIMUM.format(
@@ -365,7 +364,7 @@ class StringArray(Array):
     if string_type not in _VALID_STRING_TYPES:
       raise ValueError(_INVALID_STRING_TYPE.format(string_type))
     self._string_type = string_type
-    super(StringArray, self).__init__(shape=shape, dtype=np.object, name=name)
+    super(StringArray, self).__init__(shape=shape, dtype=object, name=name)
 
   @property
   def string_type(self):
@@ -384,7 +383,7 @@ class StringArray(Array):
     Raises:
       ValueError: if value doesn't conform to this spec.
     """
-    value = np.asarray(value, dtype=np.object)
+    value = np.asarray(value, dtype=object)
     if value.shape != self.shape:
       self._fail_validation(_INVALID_SHAPE, self.shape, value.shape)
     for item in value.flat:
