@@ -164,11 +164,13 @@ class ArrayTest(parameterized.TestCase):
 class BoundedArrayTest(parameterized.TestCase):
 
   def testInvalidMinimum(self):
-    with self.assertRaisesRegex(ValueError, "not compatible"):
+    with self.assertRaisesWithLiteralMatch(
+        ValueError, specs._MINIMUM_INCOMPATIBLE_WITH_SHAPE):
       specs.BoundedArray((3, 5), np.uint8, (0, 0, 0), (1, 1))
 
   def testInvalidMaximum(self):
-    with self.assertRaisesRegex(ValueError, "not compatible"):
+    with self.assertRaisesWithLiteralMatch(
+        ValueError, specs._MAXIMUM_INCOMPATIBLE_WITH_SHAPE):
       specs.BoundedArray((3, 5), np.uint8, 0, (1, 1, 1))
 
   def testMinMaxAttributes(self):
@@ -298,7 +300,7 @@ class BoundedArrayTest(parameterized.TestCase):
     spec.validate(test_value)
 
   def testScalarBounds(self):
-    spec = specs.BoundedArray((), np.float, minimum=0.0, maximum=1.0)
+    spec = specs.BoundedArray((), float, minimum=0.0, maximum=1.0)
 
     self.assertIsInstance(spec.minimum, np.ndarray)
     self.assertIsInstance(spec.maximum, np.ndarray)
@@ -354,7 +356,7 @@ class DiscreteArrayTest(parameterized.TestCase):
         ValueError, specs._NUM_VALUES_NOT_POSITIVE.format(num_values)):
       specs.DiscreteArray(num_values=num_values)
 
-  @parameterized.parameters(np.float32, np.object)
+  @parameterized.parameters(np.float32, object)
   def testDtypeNotIntegral(self, dtype):
     with self.assertRaisesWithLiteralMatch(
         ValueError, specs._DTYPE_NOT_INTEGRAL.format(dtype)):
@@ -452,11 +454,11 @@ class StringArrayTest(parameterized.TestCase):
       dict(
           shape=(),
           string_type=str,
-          expected=np.array(u"", dtype=np.object)),
+          expected=np.array(u"", dtype=object)),
       dict(
           shape=(1, 2),
           string_type=bytes,
-          expected=np.array([[b"", b""]], dtype=np.object)),
+          expected=np.array([[b"", b""]], dtype=object)),
   )
   def testGenerateValue(self, shape, string_type, expected):
     spec = specs.StringArray(shape=shape, string_type=string_type)
